"use client";

import { useMemo, useState } from "react";
import Link from "next/link";
import { useStudents } from "@/lib/hooks/useStudents";
import { Button } from "@/components/ui/button";
import {
  Table,
  TableBody,
  TableCell,
  TableHead,
  TableHeader,
  TableRow,
} from "@/components/ui/table";
import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuTrigger,
} from "@/components/ui/dropdown-menu";
import { Input } from "@/components/ui/input";
import {
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "@/components/ui/select";
import { Student } from "@/lib/types";
import { MoreHorizontal, Search, UserPen, UserPlus } from "lucide-react";
import { Card } from "@/components/ui/card";
import { Badge } from "@/components/ui/badge";

interface StudentListProps {
  onEdit?: (student: Student) => void;
  onView?: (student: Student) => void;
  classId?: string;
}

export function StudentList({ onEdit, onView, classId }: StudentListProps) {
  const { students, loading } = useStudents(classId);
  const [searchQuery, setSearchQuery] = useState("");
  const [statusFilter, setStatusFilter] = useState<string>("all");

  // Filter and sort students
  const filteredStudents = useMemo(() => {
    const filtered = students.filter((student) => {
      const searchLower = searchQuery.toLowerCase();
      const matchesName = 
        student.firstName.toLowerCase().includes(searchLower) ||
        student.lastName.toLowerCase().includes(searchLower);
      const matchesClassNames = student.classes?.some(cls => 
        cls.name.toLowerCase().includes(searchLower)
      ) || false;
      const matchesStatus = statusFilter === "all" || student.status === statusFilter;
      return (matchesName || matchesClassNames) && matchesStatus;
    });

    // Sort alphabetically by firstName
    return [...filtered].sort((a, b) => 
      a.firstName.localeCompare(b.firstName)
    );
  }, [students, searchQuery, statusFilter]);

  return (
    <Card className="overflow-hidden">
      <div className="p-4 flex flex-col sm:flex-row items-center justify-between gap-4 border-b">
        <div className="flex-1 flex items-center w-full">
          <div className="relative w-full max-w-sm">
            <Search className="absolute left-2.5 top-2.5 h-4 w-4 text-muted-foreground" />
            <Input
              placeholder="Search students..."
              className="pl-8"
              value={searchQuery}
              onChange={(e) => setSearchQuery(e.target.value)}
            />
          </div>
        </div>
        
        <div className="flex items-center gap-2 w-full sm:w-auto">
          <Select
            value={statusFilter}
            onValueChange={setStatusFilter}
          >
            <SelectTrigger className="w-full sm:w-[150px]">
              <SelectValue placeholder="Filter by status" />
            </SelectTrigger>
            <SelectContent>
              <SelectItem value="all">All Students</SelectItem>
              <SelectItem value="active">Active</SelectItem>
              <SelectItem value="inactive">Inactive</SelectItem>
              <SelectItem value="archived">Archived</SelectItem>
            </SelectContent>
          </Select>
          
          {/* <Link href="/students/new">
            <Button>
              <UserPen className="mr-2 h-4 w-4" />
               Student
            </Button>
          </Link> */}
        </div>
      </div>
      
      <div className="overflow-x-auto">
        <Table>
          <TableHeader>
            <TableRow>
              <TableHead>Name</TableHead>
              <TableHead>Gender</TableHead>
              <TableHead>Class</TableHead>
              <TableHead>Status</TableHead>
              <TableHead className="text-right">Actions</TableHead>
            </TableRow>
          </TableHeader>
          <TableBody>
            {loading ? (
              <TableRow>
                <TableCell colSpan={5} className="text-center py-8">
                  Loading students...
                </TableCell>
              </TableRow>
            ) : filteredStudents.length === 0 ? (
              <TableRow>
                <TableCell colSpan={5} className="text-center py-8">
                  No students found
                </TableCell>
              </TableRow>
            ) : (
              filteredStudents.map((student) => (
                <TableRow key={student.id}>
                  <TableCell>
                    <div className="font-medium">
                      {student.firstName} {student.lastName}
                    </div>
                  </TableCell>
                  <TableCell>{student.gender}</TableCell>
                  <TableCell>
                    {student.classes?.length ? (
                      <div className="flex flex-wrap gap-1">
                        {student.classes.map(cls => {
                          // Combine name with level if available
                          const displayName = cls.level 
                            ? `${cls.name} (${cls.level})` 
                            : cls.name;
                          
                          return (
                            <Badge key={cls.id} variant="outline">
                              {displayName}
                            </Badge>
                          );
                        })}
                      </div>
                    ) : (
                      "Unassigned"
                    )}
                  </TableCell>
                  <TableCell>
                    <span
                      className={`inline-flex items-center rounded-full px-2.5 py-0.5 text-xs font-medium ${
                        student.status === "active"
                          ? "bg-green-100 text-green-800 dark:bg-green-900 dark:text-green-300"
                          : student.status === "inactive"
                          ? "bg-yellow-100 text-yellow-800 dark:bg-yellow-900 dark:text-yellow-300"
                          : "bg-red-100 text-red-800 dark:bg-red-900 dark:text-red-300"
                      }`}
                    >
                      {student.status}
                    </span>
                  </TableCell>
                  <TableCell className="text-right">
                    <DropdownMenu>
                      <DropdownMenuTrigger asChild>
                        <Button variant="ghost" className="h-8 w-8 p-0">
                          <span className="sr-only">Open menu</span>
                          <MoreHorizontal className="h-4 w-4" />
                        </Button>
                      </DropdownMenuTrigger>
                      <DropdownMenuContent align="end">
                        <DropdownMenuItem onClick={() => onView && onView(student)} className="cursor-pointer">
                          View details
                        </DropdownMenuItem>
                        <DropdownMenuItem onClick={() => onEdit && onEdit(student)} className="cursor-pointer" >
                          Edit
                        </DropdownMenuItem>
                        <Link href={`/attendance?studentId=${student.id}`} passHref>
                          <DropdownMenuItem className="cursor-pointer">View attendance</DropdownMenuItem>
                        </Link>
                      </DropdownMenuContent>
                    </DropdownMenu>
                  </TableCell>
                </TableRow>
              ))
            )}
          </TableBody>
        </Table>
      </div>
    </Card>
  );
}